# Python client for Velo
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0) [![npm version](https://badge.fury.io/py/velo-python.svg)](https://badge.fury.io/py/velo-python) [![CircleCI](https://circleci.com/gh/velopaymentsapi/velo-python.svg?style=svg)](https://circleci.com/gh/velopaymentsapi/velo-python)
This library provides a Python client that simplifies interactions with the Velo Payments API. For full details covering the API visit our docs at [Velo Payments APIs](https://apidocs.velopayments.com). Note: some of the Velo API calls which require authorization via an access token, see the full docs on how to configure.
This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.35.58
- Package version: 2.35.58-beta1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import velo_payments 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import velo_payments
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import velo_payments
from velo_payments.rest import ApiException
from pprint import pprint

configuration = velo_payments.Configuration()
# Configure OAuth2 access token for authorization: OAuth2
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# Defining host is optional and default to https://api.sandbox.velopayments.com
configuration.host = "https://api.sandbox.velopayments.com"
# Create an instance of the API class
api_instance = velo_payments.CountriesApi(velo_payments.ApiClient(configuration))

try:
    # List Payment Channel Country Rules
    api_response = api_instance.list_payment_channel_rules_v1()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CountriesApi->list_payment_channel_rules_v1: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.sandbox.velopayments.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CountriesApi* | [**list_payment_channel_rules_v1**](docs/CountriesApi.md#list_payment_channel_rules_v1) | **GET** /v1/paymentChannelRules | List Payment Channel Country Rules
*CountriesApi* | [**list_supported_countries_v1**](docs/CountriesApi.md#list_supported_countries_v1) | **GET** /v1/supportedCountries | List Supported Countries
*CountriesApi* | [**list_supported_countries_v2**](docs/CountriesApi.md#list_supported_countries_v2) | **GET** /v2/supportedCountries | List Supported Countries
*CurrenciesApi* | [**list_supported_currencies_v2**](docs/CurrenciesApi.md#list_supported_currencies_v2) | **GET** /v2/currencies | List Supported Currencies
*FundingApi* | [**create_funding_request_v2**](docs/FundingApi.md#create_funding_request_v2) | **POST** /v2/sourceAccounts/{sourceAccountId}/fundingRequest | Create Funding Request
*FundingApi* | [**create_funding_request_v3**](docs/FundingApi.md#create_funding_request_v3) | **POST** /v3/sourceAccounts/{sourceAccountId}/fundingRequest | Create Funding Request
*FundingApi* | [**get_funding_account_v2**](docs/FundingApi.md#get_funding_account_v2) | **GET** /v2/fundingAccounts/{fundingAccountId} | Get Funding Account
*FundingApi* | [**get_funding_accounts_v2**](docs/FundingApi.md#get_funding_accounts_v2) | **GET** /v2/fundingAccounts | Get Funding Accounts
*FundingApi* | [**get_funding_by_id_v1**](docs/FundingApi.md#get_funding_by_id_v1) | **GET** /v1/fundings/{fundingId} | Get Funding
*FundingApi* | [**list_funding_audit_deltas**](docs/FundingApi.md#list_funding_audit_deltas) | **GET** /v1/deltas/fundings | Get Funding Audit Delta
*FundingManagerPrivateApi* | [**create_funding_account_v2**](docs/FundingManagerPrivateApi.md#create_funding_account_v2) | **POST** /v2/fundingAccounts | Create Funding Account
*FundingManagerPrivateApi* | [**delete_source_account_v3**](docs/FundingManagerPrivateApi.md#delete_source_account_v3) | **DELETE** /v3/sourceAccounts/{sourceAccountId} | Delete a source account by ID
*LoginApi* | [**logout**](docs/LoginApi.md#logout) | **POST** /v1/logout | Logout
*LoginApi* | [**reset_password**](docs/LoginApi.md#reset_password) | **POST** /v1/password/reset | Reset password
*LoginApi* | [**validate_access_token**](docs/LoginApi.md#validate_access_token) | **POST** /v1/validate | validate
*LoginApi* | [**velo_auth**](docs/LoginApi.md#velo_auth) | **POST** /v1/authenticate | Authentication endpoint
*PayeeInvitationApi* | [**create_payee_v3**](docs/PayeeInvitationApi.md#create_payee_v3) | **POST** /v3/payees | Initiate Payee Creation
*PayeeInvitationApi* | [**get_payees_invitation_status_v3**](docs/PayeeInvitationApi.md#get_payees_invitation_status_v3) | **GET** /v3/payees/payors/{payorId}/invitationStatus | Get Payee Invitation Status
*PayeeInvitationApi* | [**get_payees_invitation_status_v4**](docs/PayeeInvitationApi.md#get_payees_invitation_status_v4) | **GET** /v4/payees/payors/{payorId}/invitationStatus | Get Payee Invitation Status
*PayeeInvitationApi* | [**query_batch_status_v3**](docs/PayeeInvitationApi.md#query_batch_status_v3) | **GET** /v3/payees/batch/{batchId} | Query Batch Status
*PayeeInvitationApi* | [**query_batch_status_v4**](docs/PayeeInvitationApi.md#query_batch_status_v4) | **GET** /v4/payees/batch/{batchId} | Query Batch Status
*PayeeInvitationApi* | [**resend_payee_invite_v3**](docs/PayeeInvitationApi.md#resend_payee_invite_v3) | **POST** /v3/payees/{payeeId}/invite | Resend Payee Invite
*PayeeInvitationApi* | [**resend_payee_invite_v4**](docs/PayeeInvitationApi.md#resend_payee_invite_v4) | **POST** /v4/payees/{payeeId}/invite | Resend Payee Invite
*PayeeInvitationApi* | [**v4_create_payee**](docs/PayeeInvitationApi.md#v4_create_payee) | **POST** /v4/payees | Initiate Payee Creation
*PayeesApi* | [**delete_payee_by_id_v3**](docs/PayeesApi.md#delete_payee_by_id_v3) | **DELETE** /v3/payees/{payeeId} | Delete Payee by Id
*PayeesApi* | [**delete_payee_by_id_v4**](docs/PayeesApi.md#delete_payee_by_id_v4) | **DELETE** /v4/payees/{payeeId} | Delete Payee by Id
*PayeesApi* | [**get_payee_by_id_v3**](docs/PayeesApi.md#get_payee_by_id_v3) | **GET** /v3/payees/{payeeId} | Get Payee by Id
*PayeesApi* | [**get_payee_by_id_v4**](docs/PayeesApi.md#get_payee_by_id_v4) | **GET** /v4/payees/{payeeId} | Get Payee by Id
*PayeesApi* | [**list_payee_changes_v3**](docs/PayeesApi.md#list_payee_changes_v3) | **GET** /v3/payees/deltas | List Payee Changes
*PayeesApi* | [**list_payee_changes_v4**](docs/PayeesApi.md#list_payee_changes_v4) | **GET** /v4/payees/deltas | List Payee Changes
*PayeesApi* | [**list_payees_v3**](docs/PayeesApi.md#list_payees_v3) | **GET** /v3/payees | List Payees
*PayeesApi* | [**list_payees_v4**](docs/PayeesApi.md#list_payees_v4) | **GET** /v4/payees | List Payees
*PayeesApi* | [**payee_details_update_v3**](docs/PayeesApi.md#payee_details_update_v3) | **POST** /v3/payees/{payeeId}/payeeDetailsUpdate | Update Payee Details
*PayeesApi* | [**payee_details_update_v4**](docs/PayeesApi.md#payee_details_update_v4) | **POST** /v4/payees/{payeeId}/payeeDetailsUpdate | Update Payee Details
*PayeesApi* | [**v3_payees_payee_id_remote_id_update_post**](docs/PayeesApi.md#v3_payees_payee_id_remote_id_update_post) | **POST** /v3/payees/{payeeId}/remoteIdUpdate | Update Payee Remote Id
*PayeesApi* | [**v4_payees_payee_id_remote_id_update_post**](docs/PayeesApi.md#v4_payees_payee_id_remote_id_update_post) | **POST** /v4/payees/{payeeId}/remoteIdUpdate | Update Payee Remote Id
*PaymentAuditServiceApi* | [**export_transactions_csvv4**](docs/PaymentAuditServiceApi.md#export_transactions_csvv4) | **GET** /v4/paymentaudit/transactions | Export Transactions
*PaymentAuditServiceApi* | [**get_fundings_v4**](docs/PaymentAuditServiceApi.md#get_fundings_v4) | **GET** /v4/paymentaudit/fundings | Get Fundings for Payor
*PaymentAuditServiceApi* | [**get_payment_details_v4**](docs/PaymentAuditServiceApi.md#get_payment_details_v4) | **GET** /v4/paymentaudit/payments/{paymentId} | Get Payment
*PaymentAuditServiceApi* | [**get_payments_for_payout_v4**](docs/PaymentAuditServiceApi.md#get_payments_for_payout_v4) | **GET** /v4/paymentaudit/payouts/{payoutId} | Get Payments for Payout
*PaymentAuditServiceApi* | [**get_payout_stats_v4**](docs/PaymentAuditServiceApi.md#get_payout_stats_v4) | **GET** /v4/paymentaudit/payoutStatistics | Get Payout Statistics
*PaymentAuditServiceApi* | [**get_payouts_for_payor_v4**](docs/PaymentAuditServiceApi.md#get_payouts_for_payor_v4) | **GET** /v4/paymentaudit/payouts | Get Payouts for Payor
*PaymentAuditServiceApi* | [**list_payment_changes_v4**](docs/PaymentAuditServiceApi.md#list_payment_changes_v4) | **GET** /v4/payments/deltas | List Payment Changes
*PaymentAuditServiceApi* | [**list_payments_audit_v4**](docs/PaymentAuditServiceApi.md#list_payments_audit_v4) | **GET** /v4/paymentaudit/payments | Get List of Payments
*PaymentAuditServiceDeprecatedApi* | [**export_transactions_csvv3**](docs/PaymentAuditServiceDeprecatedApi.md#export_transactions_csvv3) | **GET** /v3/paymentaudit/transactions | V3 Export Transactions
*PaymentAuditServiceDeprecatedApi* | [**get_fundings_v1**](docs/PaymentAuditServiceDeprecatedApi.md#get_fundings_v1) | **GET** /v1/paymentaudit/fundings | V1 Get Fundings for Payor
*PaymentAuditServiceDeprecatedApi* | [**get_payment_details_v3**](docs/PaymentAuditServiceDeprecatedApi.md#get_payment_details_v3) | **GET** /v3/paymentaudit/payments/{paymentId} | V3 Get Payment
*PaymentAuditServiceDeprecatedApi* | [**get_payments_for_payout_pav3**](docs/PaymentAuditServiceDeprecatedApi.md#get_payments_for_payout_pav3) | **GET** /v3/paymentaudit/payouts/{payoutId} | V3 Get Payments for Payout
*PaymentAuditServiceDeprecatedApi* | [**get_payout_stats_v1**](docs/PaymentAuditServiceDeprecatedApi.md#get_payout_stats_v1) | **GET** /v1/paymentaudit/payoutStatistics | V1 Get Payout Statistics
*PaymentAuditServiceDeprecatedApi* | [**get_payouts_for_payor_v3**](docs/PaymentAuditServiceDeprecatedApi.md#get_payouts_for_payor_v3) | **GET** /v3/paymentaudit/payouts | V3 Get Payouts for Payor
*PaymentAuditServiceDeprecatedApi* | [**list_payment_changes**](docs/PaymentAuditServiceDeprecatedApi.md#list_payment_changes) | **GET** /v1/deltas/payments | V1 List Payment Changes
*PaymentAuditServiceDeprecatedApi* | [**list_payments_audit_v3**](docs/PaymentAuditServiceDeprecatedApi.md#list_payments_audit_v3) | **GET** /v3/paymentaudit/payments | V3 Get List of Payments
*PayorHierarchyApi* | [**payor_links_v1**](docs/PayorHierarchyApi.md#payor_links_v1) | **GET** /v1/payorLinks | List Payor Links
*PayorsApi* | [**get_payor_by_id_v1**](docs/PayorsApi.md#get_payor_by_id_v1) | **GET** /v1/payors/{payorId} | Get Payor
*PayorsApi* | [**get_payor_by_id_v2**](docs/PayorsApi.md#get_payor_by_id_v2) | **GET** /v2/payors/{payorId} | Get Payor
*PayorsApi* | [**payor_add_payor_logo_v1**](docs/PayorsApi.md#payor_add_payor_logo_v1) | **POST** /v1/payors/{payorId}/branding/logos | Add Logo
*PayorsApi* | [**payor_create_api_key_v1**](docs/PayorsApi.md#payor_create_api_key_v1) | **POST** /v1/payors/{payorId}/applications/{applicationId}/keys | Create API Key
*PayorsApi* | [**payor_create_application_v1**](docs/PayorsApi.md#payor_create_application_v1) | **POST** /v1/payors/{payorId}/applications | Create Application
*PayorsApi* | [**payor_email_opt_out**](docs/PayorsApi.md#payor_email_opt_out) | **POST** /v1/payors/{payorId}/reminderEmailsUpdate | Reminder Email Opt-Out
*PayorsApi* | [**payor_get_branding**](docs/PayorsApi.md#payor_get_branding) | **GET** /v1/payors/{payorId}/branding | Get Branding
*PayorsPrivateApi* | [**create_payor_links**](docs/PayorsPrivateApi.md#create_payor_links) | **POST** /v1/payorLinks | Create a Payor Link
*PayoutsApi* | [**create_quote_for_payout_v3**](docs/PayoutsApi.md#create_quote_for_payout_v3) | **POST** /v3/payouts/{payoutId}/quote | Create a quote for the payout
*PayoutsApi* | [**deschedule_payout**](docs/PayoutsApi.md#deschedule_payout) | **DELETE** /v3/payouts/{payoutId}/schedule | Deschedule a payout
*PayoutsApi* | [**get_payments_for_payout_v3**](docs/PayoutsApi.md#get_payments_for_payout_v3) | **GET** /v3/payouts/{payoutId}/payments | Retrieve payments for a payout
*PayoutsApi* | [**get_payout_summary_v3**](docs/PayoutsApi.md#get_payout_summary_v3) | **GET** /v3/payouts/{payoutId} | Get Payout Summary
*PayoutsApi* | [**instruct_payout_v3**](docs/PayoutsApi.md#instruct_payout_v3) | **POST** /v3/payouts/{payoutId} | Instruct Payout
*PayoutsApi* | [**schedule_for_payout**](docs/PayoutsApi.md#schedule_for_payout) | **POST** /v3/payouts/{payoutId}/schedule | Schedule a payout
*PayoutsApi* | [**submit_payout_v3**](docs/PayoutsApi.md#submit_payout_v3) | **POST** /v3/payouts | Submit Payout
*PayoutsApi* | [**withdraw_payment**](docs/PayoutsApi.md#withdraw_payment) | **POST** /v1/payments/{paymentId}/withdraw | Withdraw a Payment
*PayoutsApi* | [**withdraw_payout_v3**](docs/PayoutsApi.md#withdraw_payout_v3) | **DELETE** /v3/payouts/{payoutId} | Withdraw Payout
*SourceAccountsApi* | [**get_source_account_v2**](docs/SourceAccountsApi.md#get_source_account_v2) | **GET** /v2/sourceAccounts/{sourceAccountId} | Get Source Account
*SourceAccountsApi* | [**get_source_account_v3**](docs/SourceAccountsApi.md#get_source_account_v3) | **GET** /v3/sourceAccounts/{sourceAccountId} | Get details about given source account.
*SourceAccountsApi* | [**get_source_accounts_v2**](docs/SourceAccountsApi.md#get_source_accounts_v2) | **GET** /v2/sourceAccounts | Get list of source accounts
*SourceAccountsApi* | [**get_source_accounts_v3**](docs/SourceAccountsApi.md#get_source_accounts_v3) | **GET** /v3/sourceAccounts | Get list of source accounts
*SourceAccountsApi* | [**set_notifications_request**](docs/SourceAccountsApi.md#set_notifications_request) | **POST** /v1/sourceAccounts/{sourceAccountId}/notifications | Set notifications
*SourceAccountsApi* | [**set_notifications_request_v3**](docs/SourceAccountsApi.md#set_notifications_request_v3) | **POST** /v3/sourceAccounts/{sourceAccountId}/notifications | Set notifications
*SourceAccountsApi* | [**transfer_funds_v2**](docs/SourceAccountsApi.md#transfer_funds_v2) | **POST** /v2/sourceAccounts/{sourceAccountId}/transfers | Transfer Funds between source accounts
*SourceAccountsApi* | [**transfer_funds_v3**](docs/SourceAccountsApi.md#transfer_funds_v3) | **POST** /v3/sourceAccounts/{sourceAccountId}/transfers | Transfer Funds between source accounts
*TokensApi* | [**resend_token**](docs/TokensApi.md#resend_token) | **POST** /v2/users/{userId}/tokens | Resend a token
*UsersApi* | [**delete_user_by_id_v2**](docs/UsersApi.md#delete_user_by_id_v2) | **DELETE** /v2/users/{userId} | Delete a User
*UsersApi* | [**disable_user_v2**](docs/UsersApi.md#disable_user_v2) | **POST** /v2/users/{userId}/disable | Disable a User
*UsersApi* | [**enable_user_v2**](docs/UsersApi.md#enable_user_v2) | **POST** /v2/users/{userId}/enable | Enable a User
*UsersApi* | [**get_self**](docs/UsersApi.md#get_self) | **GET** /v2/users/self | Get Self
*UsersApi* | [**get_user_by_id_v2**](docs/UsersApi.md#get_user_by_id_v2) | **GET** /v2/users/{userId} | Get User
*UsersApi* | [**invite_user**](docs/UsersApi.md#invite_user) | **POST** /v2/users/invite | Invite a User
*UsersApi* | [**list_users**](docs/UsersApi.md#list_users) | **GET** /v2/users | List Users
*UsersApi* | [**register_sms**](docs/UsersApi.md#register_sms) | **POST** /v2/users/registration/sms | Register SMS Number
*UsersApi* | [**resend_token**](docs/UsersApi.md#resend_token) | **POST** /v2/users/{userId}/tokens | Resend a token
*UsersApi* | [**role_update**](docs/UsersApi.md#role_update) | **POST** /v2/users/{userId}/roleUpdate | Update User Role
*UsersApi* | [**unlock_user_v2**](docs/UsersApi.md#unlock_user_v2) | **POST** /v2/users/{userId}/unlock | Unlock a User
*UsersApi* | [**unregister_mfa**](docs/UsersApi.md#unregister_mfa) | **POST** /v2/users/{userId}/mfa/unregister | Unregister MFA for the user
*UsersApi* | [**unregister_mfa_for_self**](docs/UsersApi.md#unregister_mfa_for_self) | **POST** /v2/users/self/mfa/unregister | Unregister MFA for Self
*UsersApi* | [**update_password_self**](docs/UsersApi.md#update_password_self) | **POST** /v2/users/self/password | Update Password for self
*UsersApi* | [**user_details_update**](docs/UsersApi.md#user_details_update) | **POST** /v2/users/{userId}/userDetailsUpdate | Update User Details
*UsersApi* | [**user_details_update_for_self**](docs/UsersApi.md#user_details_update_for_self) | **POST** /v2/users/self/userDetailsUpdate | Update User Details for self
*UsersApi* | [**validate_password_self**](docs/UsersApi.md#validate_password_self) | **POST** /v2/users/self/password/validate | Validate the proposed password
*WebhooksApi* | [**create_webhook_v1**](docs/WebhooksApi.md#create_webhook_v1) | **POST** /v1/webhooks | Create Webhook
*WebhooksApi* | [**get_webhook_v1**](docs/WebhooksApi.md#get_webhook_v1) | **GET** /v1/webhooks/{webhookId} | Get details about the given webhook.
*WebhooksApi* | [**list_webhooks_v1**](docs/WebhooksApi.md#list_webhooks_v1) | **GET** /v1/webhooks | List the details about the webhooks for the given payor.
*WebhooksApi* | [**ping_webhook_v1**](docs/WebhooksApi.md#ping_webhook_v1) | **POST** /v1/webhooks/{webhookId}/ping | 
*WebhooksApi* | [**update_webhook_v1**](docs/WebhooksApi.md#update_webhook_v1) | **POST** /v1/webhooks/{webhookId} | Update Webhook


## Documentation For Models

 - [AcceptedPaymentV3](docs/AcceptedPaymentV3.md)
 - [AccessTokenResponse](docs/AccessTokenResponse.md)
 - [AccessTokenValidationRequest](docs/AccessTokenValidationRequest.md)
 - [AuthResponse](docs/AuthResponse.md)
 - [AutoTopUpConfigV2](docs/AutoTopUpConfigV2.md)
 - [AutoTopUpConfigV3](docs/AutoTopUpConfigV3.md)
 - [Category](docs/Category.md)
 - [ChallengeV3](docs/ChallengeV3.md)
 - [ChallengeV4](docs/ChallengeV4.md)
 - [CompanyV3](docs/CompanyV3.md)
 - [CompanyV4](docs/CompanyV4.md)
 - [CreateFundingAccountRequestV2](docs/CreateFundingAccountRequestV2.md)
 - [CreateIndividualV3](docs/CreateIndividualV3.md)
 - [CreateIndividualV3Name](docs/CreateIndividualV3Name.md)
 - [CreateIndividualV4](docs/CreateIndividualV4.md)
 - [CreatePayeeAddressV3](docs/CreatePayeeAddressV3.md)
 - [CreatePayeeAddressV4](docs/CreatePayeeAddressV4.md)
 - [CreatePayeeV3](docs/CreatePayeeV3.md)
 - [CreatePayeeV4](docs/CreatePayeeV4.md)
 - [CreatePayeesCSVRequestV3](docs/CreatePayeesCSVRequestV3.md)
 - [CreatePayeesCSVRequestV4](docs/CreatePayeesCSVRequestV4.md)
 - [CreatePayeesCSVResponseV3](docs/CreatePayeesCSVResponseV3.md)
 - [CreatePayeesCSVResponseV3RejectedCsvRows](docs/CreatePayeesCSVResponseV3RejectedCsvRows.md)
 - [CreatePayeesCSVResponseV4](docs/CreatePayeesCSVResponseV4.md)
 - [CreatePayeesRequestV3](docs/CreatePayeesRequestV3.md)
 - [CreatePayeesRequestV4](docs/CreatePayeesRequestV4.md)
 - [CreatePaymentChannelV3](docs/CreatePaymentChannelV3.md)
 - [CreatePaymentChannelV4](docs/CreatePaymentChannelV4.md)
 - [CreatePayorLinkRequest](docs/CreatePayorLinkRequest.md)
 - [CreatePayoutRequestV3](docs/CreatePayoutRequestV3.md)
 - [CreateWebhookRequest](docs/CreateWebhookRequest.md)
 - [DebitEvent](docs/DebitEvent.md)
 - [DebitEventAllOf](docs/DebitEventAllOf.md)
 - [DebitStatusChanged](docs/DebitStatusChanged.md)
 - [DebitStatusChangedAllOf](docs/DebitStatusChangedAllOf.md)
 - [Error](docs/Error.md)
 - [ErrorData](docs/ErrorData.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [FailedPayeeV3](docs/FailedPayeeV3.md)
 - [FailedPayeeV4](docs/FailedPayeeV4.md)
 - [FailedSubmissionV3](docs/FailedSubmissionV3.md)
 - [FailedSubmissionV4](docs/FailedSubmissionV4.md)
 - [FundingAccountResponseV2](docs/FundingAccountResponseV2.md)
 - [FundingAudit](docs/FundingAudit.md)
 - [FundingEvent](docs/FundingEvent.md)
 - [FundingPayorStatusAuditResponse](docs/FundingPayorStatusAuditResponse.md)
 - [FundingRequestV2](docs/FundingRequestV2.md)
 - [FundingRequestV3](docs/FundingRequestV3.md)
 - [FundingResponse](docs/FundingResponse.md)
 - [FxSummary](docs/FxSummary.md)
 - [FxSummaryV3](docs/FxSummaryV3.md)
 - [GetFundingsResponse](docs/GetFundingsResponse.md)
 - [GetFundingsResponseLinks](docs/GetFundingsResponseLinks.md)
 - [GetPayeeListResponseCompanyV3](docs/GetPayeeListResponseCompanyV3.md)
 - [GetPayeeListResponseCompanyV4](docs/GetPayeeListResponseCompanyV4.md)
 - [GetPayeeListResponseIndividualV3](docs/GetPayeeListResponseIndividualV3.md)
 - [GetPayeeListResponseIndividualV4](docs/GetPayeeListResponseIndividualV4.md)
 - [GetPayeeListResponseV3](docs/GetPayeeListResponseV3.md)
 - [GetPayeeListResponseV4](docs/GetPayeeListResponseV4.md)
 - [GetPaymentsForPayoutResponseV3](docs/GetPaymentsForPayoutResponseV3.md)
 - [GetPaymentsForPayoutResponseV3Page](docs/GetPaymentsForPayoutResponseV3Page.md)
 - [GetPaymentsForPayoutResponseV3Summary](docs/GetPaymentsForPayoutResponseV3Summary.md)
 - [GetPaymentsForPayoutResponseV4](docs/GetPaymentsForPayoutResponseV4.md)
 - [GetPaymentsForPayoutResponseV4Summary](docs/GetPaymentsForPayoutResponseV4Summary.md)
 - [GetPayoutStatistics](docs/GetPayoutStatistics.md)
 - [GetPayoutsResponse](docs/GetPayoutsResponse.md)
 - [GetPayoutsResponseV3](docs/GetPayoutsResponseV3.md)
 - [GetPayoutsResponseV3Links](docs/GetPayoutsResponseV3Links.md)
 - [GetPayoutsResponseV3Page](docs/GetPayoutsResponseV3Page.md)
 - [IndividualV3](docs/IndividualV3.md)
 - [IndividualV3Name](docs/IndividualV3Name.md)
 - [IndividualV4](docs/IndividualV4.md)
 - [InlineResponse400](docs/InlineResponse400.md)
 - [InlineResponse401](docs/InlineResponse401.md)
 - [InlineResponse403](docs/InlineResponse403.md)
 - [InlineResponse404](docs/InlineResponse404.md)
 - [InlineResponse409](docs/InlineResponse409.md)
 - [InlineResponse412](docs/InlineResponse412.md)
 - [InstructPayoutRequestV3](docs/InstructPayoutRequestV3.md)
 - [InvitePayeeRequestV3](docs/InvitePayeeRequestV3.md)
 - [InvitePayeeRequestV4](docs/InvitePayeeRequestV4.md)
 - [InviteUserRequest](docs/InviteUserRequest.md)
 - [LinkForResponse](docs/LinkForResponse.md)
 - [ListFundingAccountsResponseV2](docs/ListFundingAccountsResponseV2.md)
 - [ListFundingAccountsResponseV2Links](docs/ListFundingAccountsResponseV2Links.md)
 - [ListFundingAccountsResponseV2Page](docs/ListFundingAccountsResponseV2Page.md)
 - [ListPaymentsResponseV3](docs/ListPaymentsResponseV3.md)
 - [ListPaymentsResponseV3Page](docs/ListPaymentsResponseV3Page.md)
 - [ListPaymentsResponseV4](docs/ListPaymentsResponseV4.md)
 - [ListSourceAccountResponseV2](docs/ListSourceAccountResponseV2.md)
 - [ListSourceAccountResponseV2Links](docs/ListSourceAccountResponseV2Links.md)
 - [ListSourceAccountResponseV3](docs/ListSourceAccountResponseV3.md)
 - [ListSourceAccountResponseV3Links](docs/ListSourceAccountResponseV3Links.md)
 - [LocalisationDetails](docs/LocalisationDetails.md)
 - [MFADetails](docs/MFADetails.md)
 - [MFAType](docs/MFAType.md)
 - [NameV3](docs/NameV3.md)
 - [NameV4](docs/NameV4.md)
 - [Notification](docs/Notification.md)
 - [NotificationsV2](docs/NotificationsV2.md)
 - [NotificationsV3](docs/NotificationsV3.md)
 - [OnboardingStatusChanged](docs/OnboardingStatusChanged.md)
 - [PageForResponse](docs/PageForResponse.md)
 - [PageResourceFundingPayorStatusAuditResponseFundingPayorStatusAuditResponse](docs/PageResourceFundingPayorStatusAuditResponseFundingPayorStatusAuditResponse.md)
 - [PagedPayeeInvitationStatusResponseV3](docs/PagedPayeeInvitationStatusResponseV3.md)
 - [PagedPayeeInvitationStatusResponseV3Page](docs/PagedPayeeInvitationStatusResponseV3Page.md)
 - [PagedPayeeInvitationStatusResponseV4](docs/PagedPayeeInvitationStatusResponseV4.md)
 - [PagedPayeeResponseV3](docs/PagedPayeeResponseV3.md)
 - [PagedPayeeResponseV3Links](docs/PagedPayeeResponseV3Links.md)
 - [PagedPayeeResponseV3Page](docs/PagedPayeeResponseV3Page.md)
 - [PagedPayeeResponseV3Summary](docs/PagedPayeeResponseV3Summary.md)
 - [PagedPayeeResponseV4](docs/PagedPayeeResponseV4.md)
 - [PagedPaymentsResponseV3](docs/PagedPaymentsResponseV3.md)
 - [PagedUserResponse](docs/PagedUserResponse.md)
 - [PagedUserResponseLinks](docs/PagedUserResponseLinks.md)
 - [PagedUserResponsePage](docs/PagedUserResponsePage.md)
 - [PasswordRequest](docs/PasswordRequest.md)
 - [PayableIssueV3](docs/PayableIssueV3.md)
 - [PayableIssueV4](docs/PayableIssueV4.md)
 - [PayableStatusChanged](docs/PayableStatusChanged.md)
 - [PayeeAddressV3](docs/PayeeAddressV3.md)
 - [PayeeAddressV4](docs/PayeeAddressV4.md)
 - [PayeeDeltaResponseV3](docs/PayeeDeltaResponseV3.md)
 - [PayeeDeltaResponseV3Links](docs/PayeeDeltaResponseV3Links.md)
 - [PayeeDeltaResponseV3Page](docs/PayeeDeltaResponseV3Page.md)
 - [PayeeDeltaResponseV4](docs/PayeeDeltaResponseV4.md)
 - [PayeeDeltaResponseV4Links](docs/PayeeDeltaResponseV4Links.md)
 - [PayeeDeltaV3](docs/PayeeDeltaV3.md)
 - [PayeeDeltaV4](docs/PayeeDeltaV4.md)
 - [PayeeDetailResponseV3](docs/PayeeDetailResponseV3.md)
 - [PayeeDetailResponseV4](docs/PayeeDetailResponseV4.md)
 - [PayeeDetailsChanged](docs/PayeeDetailsChanged.md)
 - [PayeeEvent](docs/PayeeEvent.md)
 - [PayeeEventAllOf](docs/PayeeEventAllOf.md)
 - [PayeeEventAllOfReasons](docs/PayeeEventAllOfReasons.md)
 - [PayeeInvitationStatusResponseV3](docs/PayeeInvitationStatusResponseV3.md)
 - [PayeeInvitationStatusResponseV4](docs/PayeeInvitationStatusResponseV4.md)
 - [PayeePayorRefV3](docs/PayeePayorRefV3.md)
 - [PayeePayorRefV4](docs/PayeePayorRefV4.md)
 - [PayeeType](docs/PayeeType.md)
 - [PayeeTypeEnum](docs/PayeeTypeEnum.md)
 - [PayeeUserSelfUpdateRequest](docs/PayeeUserSelfUpdateRequest.md)
 - [PaymentChannelCountry](docs/PaymentChannelCountry.md)
 - [PaymentChannelRule](docs/PaymentChannelRule.md)
 - [PaymentChannelRulesResponse](docs/PaymentChannelRulesResponse.md)
 - [PaymentDelta](docs/PaymentDelta.md)
 - [PaymentDeltaResponse](docs/PaymentDeltaResponse.md)
 - [PaymentDeltaResponseV1](docs/PaymentDeltaResponseV1.md)
 - [PaymentDeltaV1](docs/PaymentDeltaV1.md)
 - [PaymentEvent](docs/PaymentEvent.md)
 - [PaymentEventAllOf](docs/PaymentEventAllOf.md)
 - [PaymentEventResponse](docs/PaymentEventResponse.md)
 - [PaymentEventResponseV3](docs/PaymentEventResponseV3.md)
 - [PaymentInstructionV3](docs/PaymentInstructionV3.md)
 - [PaymentRejectedOrReturned](docs/PaymentRejectedOrReturned.md)
 - [PaymentRejectedOrReturnedAllOf](docs/PaymentRejectedOrReturnedAllOf.md)
 - [PaymentResponseV3](docs/PaymentResponseV3.md)
 - [PaymentResponseV4](docs/PaymentResponseV4.md)
 - [PaymentResponseV4Payout](docs/PaymentResponseV4Payout.md)
 - [PaymentStatusChanged](docs/PaymentStatusChanged.md)
 - [PaymentStatusChangedAllOf](docs/PaymentStatusChangedAllOf.md)
 - [PaymentV3](docs/PaymentV3.md)
 - [PayorAddress](docs/PayorAddress.md)
 - [PayorAddressV2](docs/PayorAddressV2.md)
 - [PayorAmlTransaction](docs/PayorAmlTransaction.md)
 - [PayorAmlTransactionV3](docs/PayorAmlTransactionV3.md)
 - [PayorBrandingResponse](docs/PayorBrandingResponse.md)
 - [PayorCreateApiKeyRequest](docs/PayorCreateApiKeyRequest.md)
 - [PayorCreateApiKeyResponse](docs/PayorCreateApiKeyResponse.md)
 - [PayorCreateApplicationRequest](docs/PayorCreateApplicationRequest.md)
 - [PayorEmailOptOutRequest](docs/PayorEmailOptOutRequest.md)
 - [PayorLinksResponse](docs/PayorLinksResponse.md)
 - [PayorLinksResponseLinks](docs/PayorLinksResponseLinks.md)
 - [PayorLinksResponsePayors](docs/PayorLinksResponsePayors.md)
 - [PayorLogoRequest](docs/PayorLogoRequest.md)
 - [PayorV1](docs/PayorV1.md)
 - [PayorV2](docs/PayorV2.md)
 - [PayoutCompanyV3](docs/PayoutCompanyV3.md)
 - [PayoutIndividualV3](docs/PayoutIndividualV3.md)
 - [PayoutNameV3](docs/PayoutNameV3.md)
 - [PayoutPayeeV3](docs/PayoutPayeeV3.md)
 - [PayoutPayor](docs/PayoutPayor.md)
 - [PayoutPayorIds](docs/PayoutPayorIds.md)
 - [PayoutPrincipal](docs/PayoutPrincipal.md)
 - [PayoutSchedule](docs/PayoutSchedule.md)
 - [PayoutScheduleV3](docs/PayoutScheduleV3.md)
 - [PayoutSummaryAudit](docs/PayoutSummaryAudit.md)
 - [PayoutSummaryAuditV3](docs/PayoutSummaryAuditV3.md)
 - [PayoutSummaryResponseV3](docs/PayoutSummaryResponseV3.md)
 - [Ping](docs/Ping.md)
 - [PingResponse](docs/PingResponse.md)
 - [PostInstructFxInfo](docs/PostInstructFxInfo.md)
 - [QueryBatchResponseV3](docs/QueryBatchResponseV3.md)
 - [QueryBatchResponseV4](docs/QueryBatchResponseV4.md)
 - [QuoteFxSummaryV3](docs/QuoteFxSummaryV3.md)
 - [QuoteResponseV3](docs/QuoteResponseV3.md)
 - [RegionV2](docs/RegionV2.md)
 - [RegisterSmsRequest](docs/RegisterSmsRequest.md)
 - [RejectedPaymentV3](docs/RejectedPaymentV3.md)
 - [ResendTokenRequest](docs/ResendTokenRequest.md)
 - [ResetPasswordRequest](docs/ResetPasswordRequest.md)
 - [Role](docs/Role.md)
 - [RoleUpdateRequest](docs/RoleUpdateRequest.md)
 - [SchedulePayoutRequestV3](docs/SchedulePayoutRequestV3.md)
 - [SelfMFATypeUnregisterRequest](docs/SelfMFATypeUnregisterRequest.md)
 - [SelfUpdatePasswordRequest](docs/SelfUpdatePasswordRequest.md)
 - [SetNotificationsRequest](docs/SetNotificationsRequest.md)
 - [SetNotificationsRequest2](docs/SetNotificationsRequest2.md)
 - [SourceAccountResponseV2](docs/SourceAccountResponseV2.md)
 - [SourceAccountResponseV3](docs/SourceAccountResponseV3.md)
 - [SourceAccountSummary](docs/SourceAccountSummary.md)
 - [SourceAccountSummaryV3](docs/SourceAccountSummaryV3.md)
 - [SourceAccountV3](docs/SourceAccountV3.md)
 - [SourceEvent](docs/SourceEvent.md)
 - [SupportedCountriesResponse](docs/SupportedCountriesResponse.md)
 - [SupportedCountriesResponseV2](docs/SupportedCountriesResponseV2.md)
 - [SupportedCountry](docs/SupportedCountry.md)
 - [SupportedCountryV2](docs/SupportedCountryV2.md)
 - [SupportedCurrencyResponseV2](docs/SupportedCurrencyResponseV2.md)
 - [SupportedCurrencyV2](docs/SupportedCurrencyV2.md)
 - [TransferRequestV2](docs/TransferRequestV2.md)
 - [TransferRequestV3](docs/TransferRequestV3.md)
 - [TransmissionTypes](docs/TransmissionTypes.md)
 - [TransmissionTypes2](docs/TransmissionTypes2.md)
 - [UnregisterMFARequest](docs/UnregisterMFARequest.md)
 - [UpdatePayeeDetailsRequestV3](docs/UpdatePayeeDetailsRequestV3.md)
 - [UpdatePayeeDetailsRequestV4](docs/UpdatePayeeDetailsRequestV4.md)
 - [UpdateRemoteIdRequestV3](docs/UpdateRemoteIdRequestV3.md)
 - [UpdateRemoteIdRequestV4](docs/UpdateRemoteIdRequestV4.md)
 - [UpdateWebhookRequest](docs/UpdateWebhookRequest.md)
 - [UserDetailsUpdateRequest](docs/UserDetailsUpdateRequest.md)
 - [UserInfo](docs/UserInfo.md)
 - [UserResponse](docs/UserResponse.md)
 - [UserStatus](docs/UserStatus.md)
 - [UserType](docs/UserType.md)
 - [UserType2](docs/UserType2.md)
 - [ValidatePasswordResponse](docs/ValidatePasswordResponse.md)
 - [WebhookResponse](docs/WebhookResponse.md)
 - [WebhooksResponse](docs/WebhooksResponse.md)
 - [WithdrawPaymentRequest](docs/WithdrawPaymentRequest.md)


## Documentation For Authorization


## OAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - ** **: Scopes not required


## basicAuth

- **Type**: HTTP basic authentication


## oAuthVeloBackOffice

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - ** **: Scopes not required


## Author




